@@ -19,13 +19,18 @@ Doc.set_extension("parent_graphs_per_sent", default=[])
 def enhance_spike_doc(doc: Doc, spike_doc: JsonObject) -> JsonObject:
     converted_graphs = doc._.parent_graphs_per_sent
     for idx, sent in enumerate(spike_doc["sentences"]):
+        offset = min(token for node in converted_graphs[idx].nodes for token in node)
         sent["graphs"]["universal-enhanced"] = {"edges": [], "roots": []}
         for edge in converted_graphs[idx].edges:
             if edge.label_.lower().startswith("root"):
-                sent["graphs"]["universal-enhanced"]["roots"].append(edge.tail.tokens[0].i)  # assume we have only one token per graph node
+                sent["graphs"]["universal-enhanced"]["roots"].append(edge.tail.tokens[0].i - offset)  # assume we have only one token per graph node
             else:
                 sent["graphs"]["universal-enhanced"]["edges"].append(
-                    {"source": edge.head.tokens[0].i, "destination": edge.tail.tokens[0].i, "relation": edge.label_})
+                    {"source": edge.head.tokens[0].i - offset, "destination": edge.tail.tokens[0].i - offset, "relation": edge.label_})
+        # sort the roots and edges for consistency purposes
+        sent["graphs"]["universal-enhanced"]["roots"] = sorted(sent["graphs"]["universal-enhanced"]["roots"])
+        sent["graphs"]["universal-enhanced"]["edges"] = sorted(sent["graphs"]["universal-enhanced"]["edges"],
+                                                               key=lambda x: (x['source'], x['destination'], x['relation']))
     return spike_doc
 
 
@@ -53,16 +58,7 @@ def parse_spacy_sent(sent):
     return sentence
 
 
-def parse_bart_label(rel, is_state_head_node):
-    if rel.src is not None:
-        src = (rel.src,) + tuple(filter(None, [rel.src_type, rel.phrase]))
-    else:
-        src = "UD" if not is_state_head_node else "BART"
-    
-    return rel.with_no_bart(), src, bool(rel.uncertain), rel.iid
-
-
-def enhance_to_spacy_doc(orig_doc, converted_sentences):
+def enhance_to_spacy_doc(orig_doc, converted_sentences, remove_enhanced_extra_info, remove_bart_extra_info):
     offset = 0
     for orig_span, converted_sentence in zip(orig_doc.sents, converted_sentences):
         node_indices_map = dict()
@@ -86,8 +82,8 @@ def enhance_to_spacy_doc(orig_doc, converted_sentences):
                         node_indices_map[head_id if head_id != '0' else new_id],
                         node_indices_map[new_id]
                     ))
-                    _ = orig_doc.vocab[rel.to_str()]  # this will push the label into the vocab if it's not there
-                    labels.append(rel.to_str())
+                    _ = orig_doc.vocab[rel.to_str(remove_enhanced_extra_info, remove_bart_extra_info)]  # this will push the label into the vocab if it's not there
+                    labels.append(rel.to_str(remove_enhanced_extra_info, remove_bart_extra_info))
 
         # Disable printing possibility: so graph creation wont print many lines
         sys.stdout = open(os.devnull, 'w')
